package WikiText::Sample;
use strict;
use warnings;

use base 'WikiText';

1;

=head1 NAME

WikiText::Sample - A Sample WikiText Called "Sample"

=head1 SYNOPSIS

    use WikiText::Sample;
    
=head1 DESCRIPTION

This simple example markup consisting of H1, H2, H3, P, STRONG and EM.

=head1 AUTHOR

Ingy döt Net <ingy@cpan.org>

=head1 COPYRIGHT

Copyright (c) 2008. Ingy döt Net.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

See http://www.perl.com/perl/misc/Artistic.html

=cut
